cls
@echo off
	@ECHO *********************************************************
	@ECHO  Batch file for calibration of Atmel AVR ATxmega128A1
	@ECHO  oscillator through the JTAG interface with JTAGICE mkII
         
	@ECHO  - Programming FLASH and Fuses is performed initially.
	@ECHO  - USB port used for the JTAGICE mkII
	@ECHO  - jtagiceii.exe -h / AVR Studio help for more options
	 
	@ECHO  $Name$
	@ECHO  $Revision: 0000 $                            
	@ECHO  $RCSfile$
	@ECHO  $Date: 2009-10-15 14:28:26 +0200 (on, 30 apr 2009) $
	@ECHO *********************************************************
	@ECHO ---------------------------------------------------------
	@ECHO.
	@ECHO   ** S T A R T   P R O G R A M M I N G **
	@ECHO.		

@ECHO ---------------------------------------------------------


@REM Fill in your cpu type and full path to the programming tool
@SET CPU=ATxmega128A1
@SET TOOL="C:\Program Files\Atmel\AVR Tools\JTAGICEmkII\JTAGICEII.exe"
@SET CUSTOMERCODE="test.hex"


%TOOL% -cUSB -d %CPU% -R -e -pf -if "rc_calib.hex"

@IF ERRORLEVEL ==1 GOTO prog_Calib_code_error
		
	@ECHO.
	@ECHO  ** Start Calibration

@ECHO ---------------------------------------------------------
%TOOL% -cUSB -d %CPU% -Y

@IF ERRORLEVEL ==1 GOTO Calibration_error

@ECHO ---------------------------------------------------------
	@ECHO.
	@ECHO Verify that RC32KCAL value is different from 0xFF.
	@ECHO Note, this test is intended to fail. If it does
	@ECHO not fail, RC32KCAL equals 0xFF which is considered 
	@ECHO an error.

%TOOL% -cUSB -d %CPU% -R -ae4,4 -ve -ie "0xFF_byte.hex"

@IF ERRORLEVEL ==1 GOTO continue

@GOTO EEPROM_OSCCAL_value_error

:continue
		
@ECHO           ^^ Ignore Error above ^^
@ECHO.
@ECHO ---------------------------------------------------------
	@ECHO Read out new RC32KCAL value from EEPROM and erase the device.
	@ECHO Program in customers code to FLASH, in this case test.hex.
	@ECHO Verify programming of customers code.
        @ECHO Program in new RC32KCAL value in flash at byte addr 0800.
	@ECHO Verify programming of new RC32KCAL value in Flash.
%TOOL% -cUSB -d %CPU% -R -e -pf -vf -if%CUSTOMERCODE% -Z4 -Sf0x0800

@IF ERRORLEVEL ==1 GOTO prog_customer_code_error

	@ECHO.
	@ECHO *********************************************************
	@ECHO 		P R O G R A M M I N G   O K
	@ECHO *********************************************************
	@PAUSE

@GOTO END

:prog_Calib_code_error
	@ECHO.
@ECHO ---------------------------------------------------------
	@ECHO.
	@ECHO 		E R R O R		
	@ECHO Programming calibration program to AVR failed.
	@ECHO Programming aborted.
	@PAUSE
	@GOTO END
@ECHO !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!


:Calibration_error
	@ECHO.
@ECHO ---------------------------------------------------------
	@ECHO.
	@ECHO 		E R R O R
	@ECHO Calibration failed.
	@ECHO Programming aborted.
	@PAUSE
	@GOTO END
@ECHO !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

:EEPROM_OSCCAL_value_error
	@ECHO.
@ECHO ---------------------------------------------------------
	@ECHO.
	@ECHO 		E R R O R
	@ECHO EEPROM RC32KCAL location contain an invalid value: 0xFF
	@ECHO Programming aborted.
	@PAUSE
	@GOTO END
@ECHO !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

:prog_customer_code_error
	@ECHO.
@ECHO ---------------------------------------------------------
	@ECHO.
	@ECHO 		E R R O R
	@ECHO Programming main application program or RC32KCAL to AVR failed.
	@ECHO Programming aborted.
	@PAUSE
	@GOTO END
@ECHO !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

:END				
