//!
//! @file main.c,v
//!
//! Copyright (c) 2008 Atmel.
//!
//! @brief Main module : It is based on an infinite loop
//!
//! @version 1.21
//!

//_____  I N C L U D E S ___________________________________________________
#include "config.h"

#include "mc_interface.h"
#include "mc_control.h"
#include "mc_drv.h"
#include "DB101_IF.h"
#include "adc_drv.h"

#include "uart\uart_lib.h"
#include "ushell_task.h"
#include "clksys_driver.h"

//_____ M A C R O S ________________________________________________________


//_____ D E F I N I T I O N S ______________________________________________
//U8 __flash ramp_up_time_table[] = {26,23,20,17,14,11,8,5,3,2,2}; /* MC310 motor */
//U8 __flash ramp_up_duty_table[] = {122,124,126,129,131,133,135,137,140,143,145}; /* MC310 motor */
U8 __flash ramp_up_time_table[] = {50,34,28,24,20,18,16,12,10,8,6}; /* MC310 motor */
U8 __flash ramp_up_duty_table[] = {122,124,126,129,131,133,135,137,140,144,147}; /* MC310 motor */
//_____ D E C L A R A T I O N S ____________________________________________
U16 g_regulation_period = 0;  //!< Define the sampling period
U16 g_regulation_scale_period = 0;
U16 g_display_period = 0;     //!< Define the displaying period
U16 motor_speed = 0;          //!< User Speed Order
extern Bool g_tick;           //see mc_drv.c Use for sampling time

extern U8 duty_cycle;         //!<Parameter to set PWM Duty Cycle after regulation calculation
extern U8 duty_cycle_reference; //! Reference before filtering



  U8 ru_step_length_cntr = 0;
  U8 ru_step_before_running = 0;  
  U8 new_position = MS_001;
  U8 ru_step_length = RAMP_UP_STEP_MAX;
  U8 ru_period_counter = 0;
  U8 ramp_up_index = 0;
  U8 motor_state = MS_STOP;
  
void compute_new_position(void)
{
          if (mci_get_motor_direction()==CCW)
          {
             switch(new_position)
             {
               /* ramp up CCW */
               case MS_001:
                 new_position = MS_011;
                 break;

               case MS_101:
                 new_position = MS_001;
                 break;

               case MS_100:
                 new_position = MS_101;
                 break;

               case MS_110:
                 new_position = MS_100;
                 break;

               case MS_010:
                 new_position = MS_110;
                 break;

               case MS_011:
                 new_position = MS_010;
                 break;

               default :
                 new_position = MS_001;
                 break;
             }

          }
          else
          {
             switch(new_position)
             {
               /* ramp_up CW */
               case MS_001:
                 new_position = MS_101;
                 break;

               case MS_101:
                 new_position = MS_100;
                 break;

               case MS_100:
                 new_position = MS_110;
                 break;

               case MS_110:
                 new_position = MS_010;
                 break;

               case MS_010:
                 new_position = MS_011;
                 break;

               case MS_011:
                 new_position = MS_001;
                 break;

               default :
                 new_position = MS_001;
                 break;
             }

          }
}

void clock_init(void)
{
	/* Set system clock to 32MHz. */
	CLKSYS_Enable(OSC_RC32MEN_bm);//CLKSYS_Enable(OSC_XOSCEN_bm);
	do {} while ( CLKSYS_IsReady( OSC_RC32MRDY_bm ) == 0 );//do {} while ( CLKSYS_IsReady( OSC_XOSCRDY_bm ) == 0 );
	
	CLKSYS_PLL_Config( OSC_PLLSRC_RC32M_gc, 16 );//CLKSYS_PLL_Config( OSC_PLLSRC_XOSC_gc, 4 );
	CLKSYS_Enable(OSC_PLLEN_bm);
	CLKSYS_Prescalers_Config(CLK_PSADIV_1_gc, CLK_PSBCDIV_2_2_gc);
	do {} while ( CLKSYS_IsReady( OSC_PLLRDY_bm ) == 0 );
	CLKSYS_Main_ClockSource_Select( CLK_SCLKSEL_PLL_gc );
}


//! Main Entry
//!
//! The main entry point for the control motor application.\n
//! The mc_regulation_loop() function is launched every 80ms.\n
//!
int main(void)
{
U8 temp;
    clock_init();
  // init motor
  mc_init();  // launch initialization of the motor application

  //init_adc();

  // Initialyze the communication system for External Command through Uart
  ushell_task_init();

  mci_backward();

  mci_run();

  PMIC.CTRL |= PMIC_LOLVLEX_bm;
  __enable_interrupt();

  while(1)
  {
      // g_tick period = 1 mS
      if (g_tick == TRUE)
      {
        g_tick = FALSE;
  
        // Get Current and potentiometer value
        mc_ADC_Scheduler();
        g_regulation_scale_period += 1;
        g_display_period +=1;
        if ( (g_display_period >= 1000) && 
             ((motor_state!=MS_ALIGN)
            ||(motor_state!=MS_RAMP_UP)
            ||(motor_state!=MS_LAST_RAMP_UP))              
           )
        {
          g_display_period = 0;
          #ifdef DB101      
                  ushell_active = TRUE;
                  UpdateScreen();      
          #endif  
        }
        if ( g_regulation_scale_period >= 4 ) //n * 250us = Te = 1ms
        {
              g_regulation_scale_period = 0;
              switch(motor_state)
              {
                case (MS_ALIGN):
                  ru_period_counter--;
                  if (ru_period_counter==0)
                  {
                     motor_state=MS_RAMP_UP;
                  }
                  break;
        
                case (MS_RAMP_UP):
                  // divide the ramp-up phase in constant periods equal
                  //      to RAMP_UP_PERIOD * (g_tick periop)
                  // generate the ru_step_length for each period
                  //      with data from the table
                  ru_period_counter += 1;
                  if ( ru_period_counter >= RAMP_UP_PERIOD )
                  {
                    ru_period_counter = 0;
                    ru_step_length = ramp_up_time_table[ramp_up_index];
                    mc_duty_cycle(ramp_up_duty_table[ramp_up_index]);
                    duty_cycle = ramp_up_duty_table[ramp_up_index];
                    duty_cycle_reference = duty_cycle;
                    
                    if (ramp_up_index < RAMP_UP_INDEX_MAX)
                    {
                        ramp_up_index += 1;
                    }
                    else
                    {
                        motor_state=MS_LAST_RAMP_UP;
         
                    }
                  }
        
                  // monitor the length of each step
                  ru_step_length_cntr += 1;
                  if ( ru_step_length_cntr >= ru_step_length )
                  {
                    ru_step_length_cntr = 0;
                    compute_new_position();
                    mc_switch_commutation((Motor_Position)new_position);
                  }
                  break;
        
                case (MS_LAST_RAMP_UP):
        
                  // monitor the length of each step
                  ru_step_length_cntr += 1;
                  if ( ru_step_length_cntr >= ru_step_length )
                  {
                    ru_step_length_cntr = 0;
                    compute_new_position();
                    mc_switch_commutation((Motor_Position)new_position);
                    ru_step_before_running ++;
                    if ( ru_step_before_running >= 255)
                    {
                      ru_step_before_running = 0;
                      start_running_phase();
                      motor_state=MS_RUNNING;
                    }
                  }
                  break;
        
                case (MS_RUNNING):
                  g_regulation_period += 1;
                  if ( g_regulation_period >= 40 ) //n * 1mS = Te
                  {
                    g_regulation_period = 0;
        
                    if (ushell_active == FALSE)
                    {
                      // Set User Speed Command with potentiometer
                      temp = mc_get_potentiometer_value();
                      if (temp > (POT_REF_MIN))
                      {
                        mci_set_ref_speed((U8)temp);
                        mc_regulation_loop(); // launch regulation loop
                        mc_duty_cycle(mc_get_duty_cycle());
                      }
                      else
                      {
                        mci_set_ref_speed(POT_REF_MIN);
                        mc_regulation_loop(); // launch regulation loop
                        mc_duty_cycle(mc_get_duty_cycle());
                      }
                    }
                    else
                    {
                      mc_regulation_loop(); // launch regulation loop
                      mc_duty_cycle(mc_get_duty_cycle());
                    }
                  }
#ifdef DB101                  
                  else
                  {
                      // Set User Speed Command with potentiometer
                      temp = mc_get_potentiometer_value();
                      if (temp > (POT_REF_MIN))
                      {
                        mci_set_ref_speed((U8)temp);
                        mc_regulation_loop(); // launch regulation loop
                        mc_duty_cycle(mc_get_duty_cycle());
                      }
                      else
                      {
                        mci_set_ref_speed(POT_REF_MIN);
                        mc_regulation_loop(); // launch regulation loop
                        mc_duty_cycle(mc_get_duty_cycle());
                      }
                  }
#endif                  
                  break;
        
                case (MS_STOP):
                  if (ushell_active == FALSE)
                  {
                    temp = mc_get_potentiometer_value();
                    if (temp > (POT_REF_MIN))
                    {
                      mci_run();
                    }
                  }
                  break;
        
                default :
                  motor_state=MS_STOP;
                  break;
              }
        }
        ushell_task();
        duty_cycle_filter ();
     }
   }
}

/*  
    while(1)
    {
          
      // Launch regulation loop
      // Timer 1 generate an IT (g_tick) all 250us
      // Sampling period = n * 250us
      if (g_tick == TRUE)
      {
        g_tick = FALSE;
        mc_ADC_Scheduler();
        g_regulation_period += 1;
        if ( g_regulation_period >= 1000 ) //n * 250us = Te
        {
          g_regulation_period = 0;
  
          if (ushell_active == FALSE)
          {
            // Set User Speed Command with potentiometer
            mci_set_ref_speed(mc_get_potentiometer_value());
          }
          mc_regulation_loop(); // launch regulation loop   
  #ifdef DB101        
          UpdateScreen();      
  #endif        
        }
        ushell_task();
        mc_inrush_task(); 
      }
  
      // Show PSC state according to the Over Current information
      //if(PCTL2 & (1<<PRUN2))  switch_OFF_LED();// PSC ON
      //else  switch_ON_LED();//PSC OFF => Over_Current
    }
  }
*/